@@ -59,7 +59,9 @@ download_session_asset <- function(asset_id = 1,
     rq <- databraryr::make_default_request()
   }
   
-  
+  # Up default timeout for possibly big files
+  rq <- 
+    httr2::req_timeout(rq, seconds = 600)
   
   this_rq <- rq %>%
     httr2::req_url(sprintf(DOWNLOAD_FILE, session_id, asset_id)) %>%
@@ -77,6 +79,16 @@ download_session_asset <- function(asset_id = 1,
       NULL
   )
   
+  if (is.null(resp)) {
+    if (vb)
+      message("Request for session ",
+              session_id,
+              " asset ",
+              asset_id,
+              " returned NULL. Skipping.")
+    return(NULL)
+  }
+  
   # Gather asset format info
   format_mimetype <- NULL
   format_extension <- NULL
